<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  38760 => 'BH Telecom',
  38761 => 'BH Telecom',
  38762 => 'BH Telecom',
  38763 => 'HT ERONET',
  38764 => 'HT ERONET',
  38765 => 'm:tel',
  38766 => 'm:tel',
  38767 => 'm:tel',
);
